ESCMID: Personal data
Author: ESCMID - European Society of Clinical Microbiology and Infectious Diseases 2008
Description: Welcome to the European Society of Clinical Microbiology and Infectious Diseases
Keywords: ESCMID, European Society, Clinical Microbiology,Infectious Diseases

- Home
- Contact
- Sitemap
- Forum

Follow ESCMID on

## Membership & Organisation

- About ESCMID
- Membership
  - Terms, fees and
    membership levels
  - Online registration form
  - Offline registration
- Partners
- European cooperation

# Membership application

In ESCMID, membership application is electronic. Click on the link below and be prepared to use a valid credit card. You can register or renew your membership at any time during the year since membership is no longer related to calendar year. When you register and pay your membership dues you receive 365 days of membership (plus the number of days left from your previous payment). After successful payment you will immediate be sent a receipt, which you may use for reimbursement by your institute, if appropriate. Manual registration and payment through bank transfer can be arranged and are subject to an extra fee.

### How to sign up for a new membership

- Complete the form below
- Use a valid credit card
- A receipt will be sent immediately on successful payment.

### How to renew you membership

- Log on to the ESCMID website (email-address or ID and password). If you have forgotten your password enter your email and ask to obtain a new password. When successfully logged on to the website, your current status (type of membership, date when membership expires) is shown in the upper righthand corner.
- Click on Membership services
- Click on Membership Renewal
- Make necessary changes to your status
- Use a valid credit card
- A receipt will be sent immediately on successful payment.

# Membership application

ESCMID membership is open to all who are interested in clinical microbiology and/or infectious diseases. For registration you can either download the application form from this webpage, fill it in electronically and fax it to the Membership Office or complete the online form below (for credit card holders only: VISA, MasterCard, American Express).

## Becoming an ESCMID member or renewing

Ms (female) Mr (male)
Prof Dr
Surname(s) *
First Name(s) *
Institution / Company
Department
Street, No. (*)
P.O. Box (*)
City (State) *
Postal Code *
Country *
Nationality [Country of Passport] *

Please do not mix institutional and private addresses.

Phone
Fax
Email *
Date of Birth [DD-MM-YYYY] *

Subscription to ESCMID Online Newsletter Subscription to ESCMID Yearbook in print
I hereby agree to become a member of the European Society of Clinical Microbiology and Infectious Diseases (ESCMID), with its legal office at Aeschenvorstadt 57, CH-4051 Basel/Switzerland.
I hereby agree that my data will be saved and used exclusively for ESCMID purposes.

* = This is a required field.
(*) = Please enter either the street (name and no.) or the P.O. box.

Login
Login
Forgot password
Registration
Search
ESCMID Newsletter Sign Up
Sign Up